cookiecutter\_python.hooks package
==================================

Submodules
----------

cookiecutter\_python.hooks.pre\_gen\_project module
---------------------------------------------------

.. automodule:: cookiecutter_python.hooks.pre_gen_project
   :members:
   :undoc-members:
   :show-inheritance:

cookiecutter\_python.hooks.post\_gen\_project module
----------------------------------------------------

.. automodule:: cookiecutter_python.hooks.post_gen_project
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cookiecutter_python.hooks
   :members:
   :undoc-members:
   :show-inheritance:
